/*
 * A file accessor employing a "host" file provided via the C library.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <stdio.h>

#include "accessor.h"



/* A host filesystem file accessor, providing flexpages corresponding to file
   regions. */

class HostFileAccessor : public Accessor
{
protected:
    const char *_path;
    FILE *_fp;

    /* Data transfer helper methods. */

    virtual void fill_populated(Flexpage *flexpage);

    virtual void flush_populated(Flexpage *flexpage);

public:
    explicit HostFileAccessor(const char *path, fileid_t fileid);

    virtual void close();

    virtual void open();
};

// vim: tabstop=4 expandtab shiftwidth=4
